========================
Separation of structures
========================

.. autofunction:: ase.build.connected_indices
.. autofunction:: ase.build.connected_atoms
.. autofunction:: ase.build.separate
.. autofunction:: ase.build.split_bond
